/*
   Copyright (C) 1999 PolyWog and Javaman for Ghetto.Org
   This file is the command line component of the PCR1000 Control Suite.

   The PCR-1000 Control Suite is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The PCR-1000 Control Suite is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the PCR-1000 API Library; see the file LICENSE.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
 */

/* 
 * This file declars the PCR-1000 command line interface for the
 * Ghetto.org radio toolkit.  It implements as much of the functionality
 * as possible as defined in the API
 *
 */

#include <pcp.h>
#include <ctype.h>
#ifdef IRIX_GCC
#include <strings.h>
#else 
#include <string.h>
#endif
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

pcrfreq_t freqconv(char *);
void cmdhelp(void);

int main (int argc, char **argv)
{
	bool agc = false;  // Store setting of AGC after parsing and before transmission.
	bool nb = false;  	// Same as above, but for noise blanker.
	bool rf = false;   	// Same as above, but for RF attenuation.
	char *hz, *frac_hz;	// Pointers used in the parsing of the frequency.
	char upperword[4]; 	// Variable for converting lowercase to uppercase.
	int vol = 70;      	// Same as for AGC, but for volume.
	int sql = 40;      	// Same as for AGC, but for squelch.
	int filnum = 15;   	// Same as for AGC, but for the filter IF statements.
	int i;             	// Loop counter, used multiple times.
	float tonesq = 0;  	// Same as for AGC, but for the tone squelch.
	pcrfreq_t freq;    	// unsigned long int frequency.
	pcrcmd_t filter[11] = PCRFLTR15; // Same as for AGC, but for IF filter.
	pcrcmd_t mod[10];                // Same as for AGC, but for mod format.

	bzero(mod, sizeof(mod));

	/*
	 * If the command is issued with no arguments, issue instructions.
	 * Otherwise, instantiate a new class, parse data, and issue commands.
	 */

	if (argc > 1) {
	 	// Class instantiation here.
		PCP *rig = new PCP (PCRDEV, BAUDRATE, "RIG"); 

		if(!rig->PCPQueryOn()) {
			rig->PCPInit();  //Start up the radio.
			rig->PCPPowerUp();
		}

		/*
		 * My ghetto-assed command line parameter parsing loop.
		 * I am too lazy to learn how to use getopt(3), so this
		 * will have to do for now.  The limitation is that the
		 * value has to be attached to the parameter: -v70 for example.
		 */
		 
		while ((argc > 1) && (argv[1][0] == '-')) {
			switch ((char)tolower(argv[1][1])) {
				// Case statement for each parameter.
				case 'v':
					vol = atoi(&argv[1][2]);
					if (vol > 99 || vol < 0) {
						vol = 70;
						fprintf(stderr, "Invalid volume setting.  Volume set to %i.\n", vol);
					}
					break;

				case 'a':
					agc = true;
					break;
				
				case 'n':
					nb = true;
					break;

				case 'r':
					rf = true;
					break;

				case 't':
					hz = &argv[1][2];
					frac_hz = strchr(&argv[1][2], '.');
		
                	tonesq = (float) atoi(hz);

					if (frac_hz == NULL) {
						break;
					}
        			else {
        				*frac_hz = '\0';
        				frac_hz++;
						tonesq += ((float) atoi(frac_hz))/10;
						break;
					}

				case 's':
					sql = atoi(&argv[1][2]);
					if (sql > 99 || vol < 0) {
						sql = 40;
						fprintf(stderr, "Invalid squelch setting.  Squelch set to %i.\n", sql);
					}	
					break;

				/*
				 * The only possible filter options are 3, 6, 15, 50, and 230
				 * kHz.  The user enters these values in the command line.
				 * Otherwise, the code defaults to 15 kHz.
				 */
				case 'f':
					filnum = atoi(&argv[1][2]);

					if ((filnum == 3) || (filnum == 6) || (filnum == 15) || (filnum == 50) || (filnum == 230)) {
						strcpy(filter, &argv[1][2]);
					} else {
						strcpy(filter, "15");
						fprintf(stderr, "Invalid filter setting.  IF Filter set to 15 kHz.\n");
					}
					break;
				
				/*
				 * The first part of the following code coverts
				 * the command lime parameter to an uppercase statement.
				 * The rest determines what the actual mode passed was.
				 */
				case 'm':
					for (i = 2; argv[1][i] != '\0'; i++) {
						upperword[i-2] = (char) toupper(argv[1][i]);
					}

					upperword[i-2] = '\0';
					
					if (strncmp(upperword, "LSB", 3) == 0) {
						strcpy(mod, "LSB");
					} else if (strncmp(upperword, "USB", 3) == 0) {
						strcpy(mod, "USB");
					} else if (strncmp(upperword, "AM", 2) == 0) {
						strcpy(mod, "AM");
					} else if (strncmp(upperword, "CW", 2) == 0) {
						strcpy(mod, "CW");
					} else if (strncmp(upperword, "UNK", 3) == 0) {
						strcpy(mod, "UNK");
					} else if (strncmp(upperword, "NFM", 3) == 0) {
						strcpy(mod, "NFM");
					} else if (strncmp(upperword, "WFM", 3) == 0) {
						strcpy(mod, "WFM");
					} else {
						fprintf(stderr, "Invalid mode found.  Using NFM by default.\n");
						strcpy(mod, "NFM");
					}
					break;
			}
			++argv;
			--argc;
		}

		/*
		 * The folowing is to parse the frequency out into MHz and kHz
		 * components.  a pointer is places where the decimal is
		 * and all data from that point forward is considered to be
		 * the kHz component.
		 */

		if (argc == 2) {
			freq = freqconv(argv[1]);
		}
		else {
			fprintf(stderr, "Error: No frequency specified.\n\n");
			cmdhelp();
			exit(-1);
		}

		// Pass all the commands to the radio.
		
		if(!rig->PCPSetVolume(vol)) {
			fprintf(stderr, "Error: Cannot set volume, exiting.\n");
			cmdhelp();
			exit(-1);
		}
		if(!rig->PCPSetSquelch(sql)) {
			fprintf(stderr, "Error: Cannot set squelch, exiting.\n");
			cmdhelp();
			exit(-1);
		}
		if(!rig->PCPSetFreq(freq)) {
			fprintf(stderr, "Error: Cannot set frequency, exiting.\n");
			cmdhelp();
			exit(-1);
		}
		if(!rig->PCPSetMode(mod)) {
			fprintf(stderr, "Error: Cannot set mode, exiting.\n");
			cmdhelp();
			exit(-1);
		}

		if(!rig->PCPSetFilter(filter)) {
			fprintf(stderr, "Error: Cannot set filter, exiting.\n");
			cmdhelp();
			exit(-1);
		}
		if(!rig->PCPSetToneSq(tonesq)) {
			fprintf(stderr, "Error: Cannot set tone squelch, exiting.\n");
			cmdhelp();
			exit(-1);
		}
		if(!rig->PCPSetAutoGain(agc)) {
			fprintf(stderr, "Error: Cannot set AGC, exiting.\n");
			cmdhelp();
			exit(-1);
		}
		if(!rig->PCPSetNB(nb)) {
			fprintf(stderr, "Error: Cannot set NB, exiting.\n");
			cmdhelp();
			exit(-1);
		}
		if(!rig->PCPSetRFAttenuator(rf)) {
			fprintf(stderr, "Error: Cannot set RF Attenuator, exiting.\n");
			cmdhelp();
			exit(-1);
		}

		printf("Command successful.\nFrequency: %i hz; Signal Strength: %i.\n", freq, rig->PCPSigStrength());
	}
	else {
		cmdhelp();
	}
	return(0);
}

void cmdhelp(void)
{
		printf("\npcr version 0.9 written by Polywog and Javaman.\n");
		printf("PCR-1000 is assumed to be on the /dev/pcr1000 port.\n");
		printf("Usage is pcr [-v<volume>] [-s<squelch>] [-f<filter>] [-m<mode>] [-t<freq>] [-a] [-n] [-r] freq (in MHz)\n\n");
		printf("Options:\n");
		printf("   -v\t= Set volume (00 through 99)\n");
		printf("   -s\t= Set squelch (00 through 99)\n");
		printf("   -f\t= Set filter (3, 6, 15, 50, 230)\n");
		printf("   -m\t= Set mode (usb, lsb, am, cw, nfm, wfm)\n");
		printf("   -t\t= Set tone squelch (103.5, 141.3)\n");
		printf("   -a\t= Turn AGC on\n");
		printf("   -n\t= Turn the noise blanker on\n");
		printf("   -r\t= Turn the RF attenuator on\n");
		printf("   freq\t = Frequency in megahertz\n\n");
		printf("Example:\n\tpcr -v70 -s40 -f15 -mnfm 146.52\n");
}

pcrfreq_t freqconv(char *strfreq)
{
	pcrfreq_t tempfreq;
	char *mhz, *khz;
	int i;

	mhz = strfreq;
	khz = strchr(strfreq, '.');

	if (khz == NULL) {
		if (strlen(mhz) > 4) {
			fprintf(stderr, "Malformed frequency: %s\n", strfreq);
           	exit(-1);
       	}
       	tempfreq = atoi(mhz) * 1000000;
       	return tempfreq;
   	}
   	else
   	*khz = '\0';
   	khz++;
	tempfreq = atoi(khz);

   	for (i = 5; i >= strlen(khz) ; i--)
        tempfreq *= 10;

   	tempfreq += atoi(mhz) * 1000000;

	return tempfreq;
}
