/*
 *   QPcr1k
 *   Copyright (C) 1999 by PolyWog and Javaman for Ghetto.Org
 *    <polywog@ghetto.org>, <javaman@ghetto.org>
 *
 *   A GUI front end using the QT Toolkit and PCP/PCOMM library
 *   for the Icom Pcr-1000 radio.
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include <qpushbutton.h>
#include <qwidget.h>
#include <qlayout.h>
#include <qstring.h>
#include <qlabel.h>
#include <qtooltip.h>

#include "pkeybd.h"

PKeyBoard :: PKeyBoard (QWidget *parent, const char *name)
           : QWidget(parent, name)
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: Creating...\n");
    #endif // DEBUG_VER_

    PKGrid = new QGridLayout(this, 4, 4, 0, -1, "pkgrid_qlayout");
    PK01 = new QPushButton("1",     this, "pk01_qpushbutton");
    PK02 = new QPushButton("2",     this, "pk02_qpushbutton");
    PK03 = new QPushButton("3",     this, "pk03_qpushbutton");
    PK04 = new QPushButton("4",     this, "pk04_qpushbutton");
    PK05 = new QPushButton("5",     this, "pk05_qpushbutton");
    PK06 = new QPushButton("6",     this, "pk06_qpushbutton");
    PK07 = new QPushButton("7",     this, "pk07_qpushbutton");
    PK08 = new QPushButton("8",     this, "pk08_qpushbutton");
    PK09 = new QPushButton("9",     this, "pk09_qpushbutton");
    PKST = new QPushButton("<<",    this, "pk11_qpushbutton");
        QToolTip::add(PKST, "Channel Down");
    PK00 = new QPushButton("0",     this, "pk10_qpushbutton");
    PKPD = new QPushButton(">>",    this, "pk12_qpushbutton");
        QToolTip::add(PKPD, "Channel Up");
    PKEN = new QPushButton("Enter", this, "pken_qpushbutton");
    PKDT = new QPushButton(".",     this, "pkdt_qpushbutton");
    PKCR = new QPushButton("Clear", this, "pkcr_qpushbutton");


    PKGrid->addWidget(PK01, 0, 0);
    PKGrid->addWidget(PK02, 0, 1);
    PKGrid->addWidget(PK03, 0, 2);
    PKGrid->addWidget(PK04, 1, 0);
    PKGrid->addWidget(PK05, 1, 1);
    PKGrid->addWidget(PK06, 1, 2);
    PKGrid->addWidget(PK07, 2, 0);
    PKGrid->addWidget(PK08, 2, 1);
    PKGrid->addWidget(PK09, 2, 2);
    PKGrid->addWidget(PKST, 3, 0);
    PKGrid->addWidget(PK00, 3, 1);
    PKGrid->addWidget(PKPD, 3, 2);

    PKGrid->addWidget(PKDT, 0, 3);
    PKGrid->addWidget(PKCR, 1, 3);
    PKGrid->addMultiCellWidget(PKEN, 2, 3, 3, 3);

    //PKGrid->resize(PKGrid->sizeHint());
    PKGrid->activate();

    connect(PK01, SIGNAL(clicked()), SLOT(key1PressSlot()) );
    connect(PK02, SIGNAL(clicked()), SLOT(key2PressSlot()) );
    connect(PK03, SIGNAL(clicked()), SLOT(key3PressSlot()) );
    connect(PK04, SIGNAL(clicked()), SLOT(key4PressSlot()) );
    connect(PK05, SIGNAL(clicked()), SLOT(key5PressSlot()) );
    connect(PK06, SIGNAL(clicked()), SLOT(key6PressSlot()) );
    connect(PK07, SIGNAL(clicked()), SLOT(key7PressSlot()) );
    connect(PK08, SIGNAL(clicked()), SLOT(key8PressSlot()) );
    connect(PK09, SIGNAL(clicked()), SLOT(key9PressSlot()) );
    connect(PKST, SIGNAL(clicked()), SLOT(keySPressSlot()) );
    connect(PK00, SIGNAL(clicked()), SLOT(key0PressSlot()) );
    connect(PKPD, SIGNAL(clicked()), SLOT(keyPPressSlot()) );
    connect(PKDT, SIGNAL(clicked()), SLOT(keyDPressSlot()) );
    connect(PKEN, SIGNAL(clicked()), SLOT(keyEPressSlot()) );
    connect(PKCR, SIGNAL(clicked()), SLOT(keyRPressSlot()) );

    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: Created!\n");
    #endif // DEBUG_VER_
}

PKeyBoard :: ~PKeyBoard()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: Destroyed!\n");
    #endif // DEBUG_VER_
}

void PKeyBoard :: key1PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY1PRESSSLOT\n" );
    #endif // DEBUG_VER_

    emit keyPressCall("1");
}

void PKeyBoard :: key2PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY2PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("2");
}

void PKeyBoard :: key3PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY3PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("3");
}

void PKeyBoard :: key4PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY4PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("4");
}

void PKeyBoard :: key5PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY5PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("5");
}

void PKeyBoard :: key6PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY6PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("6");
}

void PKeyBoard :: key7PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY7PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("7");
}

void PKeyBoard :: key8PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY8PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("8");
}

void PKeyBoard :: key9PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY9PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("9");
}

void PKeyBoard :: keySPressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEYSPRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("<");
}

void PKeyBoard :: key0PressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEY0PRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("0");
}

void PKeyBoard :: keyPPressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEYPPRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall(">");
}

void PKeyBoard :: keyDPressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEYDPRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall(".");
}

void PKeyBoard :: keyEPressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEYEPRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall(";");
}

void PKeyBoard :: keyRPressSlot()
{
    #ifdef DEBUG_VER_
    fprintf(stderr, "PKeyBoard: SLOT-KEYRPRESSSLOT\n" );
    #endif // DEBUG_VER_
    emit keyPressCall("R");
}
